﻿using System;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.ChangeTracking;
using Microsoft.EntityFrameworkCore.Diagnostics;

namespace MyERP2.DBContext
{
    public class MyERP2Context : Microsoft.EntityFrameworkCore.DbContext
    {
        public MyERP2Context() { }
        public MyERP2Context(string sqlConnectionString) : this(new DbContextOptionsBuilder<MyERP2Context>().UseSqlServer(sqlConnectionString).Options){}

        internal MyERP2Context(DbContextOptions options) : base(options) { }

        //Defining the Entities:
        //public virtual DbSet<Model.StorageModel.StoreInfo> StoreInfos { get; set; }







        //Defining the Model

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            if (!optionsBuilder.IsConfigured)
            {
                //Here we have to define a specific server based on the selection during login
                optionsBuilder.UseSqlServer(@"Server=(localdb)\mssqllocaldb;Database=MyERP2;Trusted_Connection=True;")
                        .ConfigureWarnings(warnings => warnings.Throw(CoreEventId.IncludeIgnoredWarning));
            }
        }


        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            //Define the model itself
            //modelBuilder.Entity<Model.StorageModel.Article>().HasOne(a => a.StoreInfo).WithOne(b => b.Article).HasForeignKey<Model.StorageModel.StoreInfo>(c => c.StoreInfoId);
            //modelBuilder.Entity<Model.StorageModel.Article>().HasOne(a => a.StoreInfo).WithOne(b => b.Article).HasForeignKey<Model.StorageModel.Article>(c => c.ArticleId);
        }



        public override int SaveChanges()
        {
            UpdateEntitysBeforeSaving();
            return base.SaveChanges();
        }

        public override Task<int> SaveChangesAsync(bool acceptAllChangesOnSuccess, CancellationToken cancellationToken = default(CancellationToken))
        {
            UpdateEntitysBeforeSaving();
            return base.SaveChangesAsync(acceptAllChangesOnSuccess, cancellationToken);
        }

        /// <summary>
        /// Detaches all of the EntityEntry objects that have been added to the ChangeTracker.
        /// </summary>
        public void DetachAll()
        {
            foreach (EntityEntry entityEntry in ChangeTracker.Entries().ToArray())
            {
                if (entityEntry.Entity != null)
                {
                    entityEntry.State = EntityState.Detached;
                }
            }
        }



        private void UpdateEntitysBeforeSaving()
        {
            var objectStateEntries = ChangeTracker.Entries()
           .Where(e => e.Entity is ModelBase && e.State != EntityState.Detached && e.State != EntityState.Unchanged).ToList();

            foreach (var entry in objectStateEntries)
            {
                if (!(entry.Entity is ModelBase entityBase)) continue;
                switch (entry.State)
                {
                    case EntityState.Deleted:
                        if (entityBase is ILogicalDelete delete)
                        {
                            entry.State = EntityState.Modified;

                            delete.DeletedTimestamp = DateTime.Now;
                            delete.DeletedFlag = true;
                            entry.Property(nameof(delete.DeletedTimestamp)).IsModified = true;
                            entry.Property(nameof(delete.DeletedFlag)).IsModified = true;
                        }
                        break;
                    case EntityState.Modified:

                        if (entityBase is ILogicalTimestamp timestamp)
                        {
                            timestamp.LastUpdateTimestamp = DateTime.Now;
                            entry.Property(nameof(timestamp.LastUpdateTimestamp)).IsModified = true;

                        }
                        if (entityBase is ILogicalDelete deleteedited)
                        {
                            string originalvalue = entry.Property(nameof(deleteedited.DeletedFlag)).OriginalValue.ToString();
                            string currentValue = entry.Property(nameof(deleteedited.DeletedFlag)).CurrentValue.ToString();
                            bool.TryParse(originalvalue, out var result);
                            bool.TryParse(currentValue, out var result1);
                            if (result != result1)
                            {
                                deleteedited.DeletedTimestamp = DateTime.Now;
                                entry.Property(nameof(deleteedited.DeletedTimestamp)).IsModified = true;
                            }
                        }
                        break;
                    case EntityState.Added:
                        if (entityBase is ILogicalTimestamp logicalTimestamp)
                        {
                            logicalTimestamp.CreationTimestamp = DateTime.Now;
                            logicalTimestamp.LastUpdateTimestamp = DateTime.Now;
                            entry.Property(nameof(logicalTimestamp.CreationTimestamp)).IsModified = true;
                            entry.Property(nameof(logicalTimestamp.LastUpdateTimestamp)).IsModified = true;
                        }
                        break;
                }

            }

        }

    }
}
