﻿'
'  In App.xaml:
'  <Application.Resources>
'      <vm:ViewModelLocator xmlns:vm="clr-namespace:HHHB3"
'                           x:Key="Locator" />
'  </Application.Resources>
'  
'  In the View:
'  DataContext="{Binding Source={StaticResource Locator}, Path=ViewModelName}"
'
'  You can also use Blend to do all this with the tool's support.
'  See http://www.galasoft.ch/mvvm
'


Imports GalaSoft.MvvmLight
Imports GalaSoft.MvvmLight.Ioc
Imports GalaSoft.MvvmLight.Views

Namespace MyErp.ViewModel
    ''' <summary>
    ''' This class contains static references to all the view models in the
    ''' application and provides an entry point for the bindings.
    ''' </summary>
    Public Class ViewModelLocator
        ''' <summary>
        ''' Initializes a new instance of the ViewModelLocator class.
        ''' </summary>
        Public Sub New()
            SimpleIoc.[Default].Register(Of MainViewModel)()

            'Generals:
            SimpleIoc.Default.Register(Of VMSearchForm)() 'Searchform
            SimpleIoc.Default.Register(Of VMDirectSearch)() 'Direct Search Usercontrol
            SimpleIoc.Default.Register(Of VMFilterForm)() 'FilterForm
            SimpleIoc.Default.Register(Of VMSelectNumberRange)() 'Selection Form for Numberranges
            SimpleIoc.Default.Register(Of VMItemNotes)() 'Form to display notes of an item
            SimpleIoc.Default.Register(Of VMDataGridSettings)() 'Form to change view settings of a datagrid

            'Module Articles:
            SimpleIoc.Default.Register(Of VMArticleMenu)() 'Article Menu
            SimpleIoc.Default.Register(Of VMArticlesOverview)() 'Article Overview
            SimpleIoc.Default.Register(Of VMArticleAddEdit)() 'Article Add/Edit
            SimpleIoc.Default.Register(Of VMArticleStatistics)() 'Article Statistics
            SimpleIoc.Default.Register(Of VMTextDescriptionsOverview)() 'Preset Textelements Overview
            SimpleIoc.Default.Register(Of VMTextDescriptionOverviewAddEdit)() 'Preset Textelement add/edit
            SimpleIoc.Default.Register(Of VMArticleTextEdit)() ' Article Texts

            'Module Sales:
            SimpleIoc.Default.Register(Of VMSalesMenu)() 'Sales Menu
            SimpleIoc.Default.Register(Of VMSalesContacts)() 'Contactmanagement
            SimpleIoc.Default.Register(Of VMContactTypes)() 'Contact Types
            SimpleIoc.Default.Register(Of VMClientStatus)() 'Client Status
            SimpleIoc.Default.Register(Of VMDiscountGroups)() 'Discount Groups
            SimpleIoc.Default.Register(Of VMArticleSalesPrices)() ' Article Sales Prices

            'Module Administration:
            SimpleIoc.Default.Register(Of VMAdministrationMenu)() 'Administration Menu
            SimpleIoc.Default.Register(Of VMAdminNumberRanges)() 'NumberLogic
            SimpleIoc.Default.Register(Of VMAdminUsers)() 'Users
            SimpleIoc.Default.Register(Of VMUserUserGroups)() 'User Usergroups
            SimpleIoc.Default.Register(Of VMAdminUserGroups)() 'Usergroups
            SimpleIoc.Default.Register(Of VMUserGroupAuthorizations)() ' Usergroup Authorizations
            SimpleIoc.Default.Register(Of VMIncoterms)() 'Incoterms
            SimpleIoc.Default.Register(Of VMUnits)() 'Units
            SimpleIoc.Default.Register(Of VMLanguages)() 'Langugages
            SimpleIoc.Default.Register(Of VMArticleStatus)() 'Article Status Collection
            SimpleIoc.Default.Register(Of VMAdressTypes)() 'Adress Types

            'Module Purchase:
            SimpleIoc.Default.Register(Of VMPurchaseMenu)() 'Purchase Menu
            SimpleIoc.Default.Register(Of VMSuppliersOverview)() 'Suppliers Overview
            SimpleIoc.Default.Register(Of VMSupplierStatistics)() 'Supplier Statistics
            SimpleIoc.Default.Register(Of VMSupplierAddEdit)() 'Supplier Add/Edit

            'Module Accounting:
            SimpleIoc.Default.Register(Of VMAccountingMenu)() 'Accouting Menu
            SimpleIoc.Default.Register(Of VMLegalForms)() 'Legal Forms
            SimpleIoc.Default.Register(Of VMCurrencies)() 'Currencies
            SimpleIoc.Default.Register(Of VMVATGroups)() 'VAT Groups

            'Module Stock:
            SimpleIoc.Default.Register(Of VMStockMenu)() 'Stock Menu

        End Sub

        Public ReadOnly Property MainModel() As MainViewModel
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of MainViewModel)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

#Region "Generals"

        Public ReadOnly Property SearchModel() As VMSearchForm
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMSearchForm)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property DirectSearch() As VMDirectSearch
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMDirectSearch)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property FilterForm() As VMFilterForm
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMFilterForm)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property SelectNumberRange() As VMSelectNumberRange
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMSelectNumberRange)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property ItemNotes() As VMItemNotes
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMItemNotes)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property DataGridSettings() As VMDataGridSettings
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMDataGridSettings)(id)
                instance.Id = id
                Return instance
            End Get
        End Property
#End Region

#Region "Article-Module"
        Public ReadOnly Property ArticleMenu() As VMArticleMenu
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMArticleMenu)(id)
                instance.Id = id
                Return instance
            End Get
        End Property
        Public ReadOnly Property ArticlesOverview() As VMArticlesOverview
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMArticlesOverview)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property ArticleAddEdit() As VMArticleAddEdit
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMArticleAddEdit)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property ArticleStatistics() As VMArticleStatistics
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMArticleStatistics)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property TextDescriptionsOverview() As VMTextDescriptionsOverview
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMTextDescriptionsOverview)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property TextDescriptionOverviewAddEdit() As VMTextDescriptionOverviewAddEdit
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMTextDescriptionOverviewAddEdit)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property ArticleTextEdit() As VMArticleTextEdit
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMArticleTextEdit)(id)
                instance.Id = id
                Return instance
            End Get
        End Property
#End Region

#Region "Sales-Module"
        Public ReadOnly Property SalesMenu() As VMSalesMenu
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMSalesMenu)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property SalesContacts() As VMSalesContacts
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMSalesContacts)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property ContactTypes() As VMContactTypes
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMContactTypes)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property ClientStatus() As VMClientStatus
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMClientStatus)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property DiscountGroups() As VMDiscountGroups
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMDiscountGroups)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property ArticleSalesPrices() As VMArticleSalesPrices
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMArticleSalesPrices)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

#End Region

#Region "Purchase-Module"
        Public ReadOnly Property PurchaseMenu() As VMPurchaseMenu
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMPurchaseMenu)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property SuppliersOverview() As VMSuppliersOverview
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMSuppliersOverview)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property SupplierAddEdit() As VMSupplierAddEdit
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMSupplierAddEdit)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property SupplierStatistics() As VMSupplierStatistics
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMSupplierStatistics)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

#End Region

#Region "Accouting"
        Public ReadOnly Property AccountingMenu() As VMAccountingMenu
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMAccountingMenu)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property LegalForms() As VMLegalForms
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMLegalForms)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property Currencies() As VMCurrencies
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMCurrencies)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property VATGroups() As VMVATGroups
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMVATGroups)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

#End Region

#Region "Administration-Module"

        Public ReadOnly Property AdministrationMenu() As VMAdministrationMenu
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMAdministrationMenu)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property AdminNumberRanges() As VMAdminNumberRanges
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMAdminNumberRanges)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property AdminUsers() As VMAdminUsers
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMAdminUsers)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property AdminUserUserGroups() As VMUserUserGroups
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMUserUserGroups)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property AdminUserGroups() As VMAdminUserGroups
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMAdminUserGroups)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property AdminUserGroupAuthorizations() As VMUserGroupAuthorizations
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMUserGroupAuthorizations)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property Incoterms() As VMIncoterms
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMIncoterms)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property Units() As VMUnits
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMUnits)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property Languages() As VMLanguages
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMLanguages)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property ArticleStatus() As VMArticleStatus
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMArticleStatus)(id)
                instance.Id = id
                Return instance
            End Get
        End Property

        Public ReadOnly Property AdressTypes() As VMAdressTypes
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMAdressTypes)(id)
                instance.Id = id
                Return instance
            End Get
        End Property
#End Region

#Region "Stock-Module"

        Public ReadOnly Property StockMenu() As VMStockMenu
            Get
                Dim id As String = Guid.NewGuid.ToString
                Dim instance = SimpleIoc.Default.GetInstance(Of VMStockMenu)(id)
                instance.Id = id
                Return instance
            End Get
        End Property
#End Region



        Public Shared Sub Cleanup()
            ' TODO Clear the ViewModels
            SimpleIoc.Default.Reset()

            'With SimpleIoc.Default
            '    If .IsRegistered(Of MainViewModel) Then .Unregister(Of MainViewModel)()
            '    'Generals:
            '    If .IsRegistered(Of VMSearchForm) Then .Unregister(Of VMSearchForm)()
            '    If .IsRegistered(Of VMArticleStatistics) Then .Unregister(Of VMArticleStatistics)()
            '    If .IsRegistered(Of VMSelectNumberRange) Then .Unregister(Of VMSelectNumberRange)()
            '    If .IsRegistered(Of VMItemNotes) Then .Unregister(Of VMItemNotes)()
            '    If .IsRegistered(Of VMDataGridSettings) Then .Unregister(Of VMDataGridSettings)()
            '    'Articles:
            '    If .IsRegistered(Of VMArticleMenu) Then .Unregister(Of VMArticleMenu)()
            '    If .IsRegistered(Of VMArticlesOverview) Then .Unregister(Of VMArticlesOverview)()
            '    If .IsRegistered(Of VMArticleAddEdit) Then .Unregister(Of VMArticleAddEdit)()
            '    'Sales:
            '    If .IsRegistered(Of VMSalesMenu) Then .Unregister(Of VMSalesMenu)()
            '    If .IsRegistered(Of VMSalesContacts) Then .Unregister(Of VMSalesContacts)()
            '    If .IsRegistered(Of VMContactTypes) Then .Unregister(Of VMContactTypes)()
            '    If .IsRegistered(Of VMClientStatus) Then .Unregister(Of VMClientStatus)()
            '    If .IsRegistered(Of VMDiscountGroups) Then .Unregister(Of VMDiscountGroups)()
            '    If .IsRegistered(Of VMArticleSalesPrices) Then .Unregister(Of VMArticleSalesPrices)()
            '    'Purchase:
            '    If .IsRegistered(Of VMSupplierStatus) Then .Unregister(Of VMSupplierStatus)()
            '    'Accouting:
            '    If .IsRegistered(Of VMAccountingMenu) Then .Unregister(Of VMAccountingMenu)()
            '    If .IsRegistered(Of VMLegalForms) Then .Unregister(Of VMLegalForms)()
            '    If .IsRegistered(Of VMCurrencies) Then .Unregister(Of VMCurrencies)()
            '    If .IsRegistered(Of VMVATGroups) Then .Unregister(Of VMVATGroups)()
            '    'Administration:
            '    If .IsRegistered(Of VMAdministrationMenu) Then .Unregister(Of VMAdministrationMenu)()
            '    If .IsRegistered(Of VMAdminNumberRanges) Then .Unregister(Of VMAdminNumberRanges)()
            '    If .IsRegistered(Of VMAdminUserGroups) Then .Unregister(Of VMAdminUserGroups)()
            '    If .IsRegistered(Of VMUserGroupAuthorizations) Then .Unregister(Of VMUserGroupAuthorizations)()
            '    If .IsRegistered(Of VMAdminUsers) Then .Unregister(Of VMAdminUsers)()
            '    If .IsRegistered(Of VMUserUserGroups) Then .Unregister(Of VMUserUserGroups)()
            '    If .IsRegistered(Of VMIncoterms) Then .Unregister(Of VMIncoterms)()
            '    If .IsRegistered(Of VMUnits) Then .Unregister(Of VMUnits)()
            '    If .IsRegistered(Of VMLanguages) Then .Unregister(Of VMLanguages)()
            '    If .IsRegistered(Of VMArticleStatus) Then .Unregister(Of VMArticleStatus)()
            '    If .IsRegistered(Of VMAdressTypes) Then .Unregister(Of VMAdressTypes)()
            '    'Stock
            '    If .IsRegistered(Of VMStockMenu) Then .Unregister(Of VMStockMenu)()

            'End With
        End Sub

        Public Shared Sub UnregisterMainViewModel(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of MainViewModel)(id)
        End Sub

        Public Shared Sub UnregisterVMSearchForm(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMSearchForm)(id)
        End Sub

        Public Shared Sub UnregisterVMArticleStatistics(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMArticleStatistics)(id)
        End Sub

        Public Shared Sub UnregisterVMSalesContacts(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMSalesContacts)(id)
        End Sub

        Public Shared Sub UnregisterVMAdminNumberRanges(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMAdminNumberRanges)(id)
        End Sub

        Public Shared Sub UnregisterVMIncoterms(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMIncoterms)(id)
        End Sub

        Public Shared Sub UnregisterVMContactTypes(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMContactTypes)(id)
        End Sub

        Public Shared Sub UnregisterVMClientStatus(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMClientStatus)(id)
        End Sub

        Public Shared Sub UnregisterVMUnits(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMUnits)(id)
        End Sub

        Public Shared Sub UnregisterVMLanguages(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMLanguages)(id)
        End Sub

        Public Shared Sub UnregisterVMArticleStatus(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMArticleStatus)(id)
        End Sub

        Public Shared Sub UnregisterVMAdressTypes(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMAdressTypes)(id)
        End Sub

        Public Shared Sub UnregisterVMLegalForms(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMLegalForms)(id)
        End Sub

        Public Shared Sub UnregisterVMCurrencies(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMCurrencies)(id)
        End Sub
        Public Shared Sub UnregisterVMAccountingMenu(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMAccountingMenu)(id)
        End Sub

        Public Shared Sub UnregisterVMAdminUserGroups(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMAdminUserGroups)(id)
        End Sub

        Public Shared Sub UnregisterVMAdminUsers(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMAdminUsers)(id)
        End Sub

        Public Shared Sub UnregisterVMUserUserGroups(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMUserUserGroups)(id)
        End Sub

        Public Shared Sub UnregisterVMSalesArticlesOverview(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMArticlesOverview)(id)
        End Sub

        Public Shared Sub UnregisterVMArticleAddEdit(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMArticleAddEdit)(id)
        End Sub

        Public Shared Sub UnregisterVMSelectNumberRange(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMSelectNumberRange)(id)
        End Sub

        Public Shared Sub UnregisterVMVATGroups(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMVATGroups)(id)
        End Sub

        Public Shared Sub UnregisterVMDiscountGroups(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMDiscountGroups)(id)
        End Sub

        Public Shared Sub UnregisterVMArticleSalesPrices(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMArticleSalesPrices)(id)
        End Sub

        Public Shared Sub UnregisterVMItemNotes(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMItemNotes)(id)
        End Sub

        Public Shared Sub UnregisterVMDataGridSettings(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMDataGridSettings)(id)
        End Sub

        Public Shared Sub UnregisterVMTextDescriptionsOverview(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMTextDescriptionsOverview)(id)
        End Sub

        Public Shared Sub UnregisterVMTextDescriptionOverviewAddEdit(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMTextDescriptionOverviewAddEdit)(id)
        End Sub

        Public Shared Sub UnregisterVMArticleTextEdit(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMArticleTextEdit)(id)
        End Sub

        Public Shared Sub UnregisterVMPurchaseMenu(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMPurchaseMenu)(id)
        End Sub

        Public Shared Sub UnregisterVMSuppliersOverview(ByVal id As String)
            SimpleIoc.[Default].Unregister(Of VMSuppliersOverview)(id)
        End Sub

    End Class
End Namespace